Crate kcr_couchbase_com

Crate kcr_couchbase_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the couchbase.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

couchbase.com/v2

  • CouchbaseAutoscaler
  • CouchbaseBackupRestore
  • CouchbaseBackup
  • CouchbaseBucket
  • CouchbaseCluster
  • CouchbaseCollectionGroup
  • CouchbaseCollection
  • CouchbaseEphemeralBucket
  • CouchbaseGroup
  • CouchbaseMemcachedBucket
  • CouchbaseMigrationReplication
  • CouchbaseReplication
  • CouchbaseRoleBinding
  • CouchbaseScopeGroup
  • CouchbaseScope
  • CouchbaseUser

Modules

v2