CouchbaseBackupData

Struct CouchbaseBackupData 

pub struct CouchbaseBackupData {
    pub exclude: Option<Vec<String>>,
    pub include: Option<Vec<String>>,
}
Data allows control over what key-value/document data is included in the backup. By default, all data is included. Modifications to this field will only take effect on the next full backup.

Fields

exclude: Option<Vec<String>>

Exclude defines the buckets, scopes or collections that are excluded from the backup. When this field is set, it implies that by default everything will be backed up, and data items can be explicitly excluded. You may define an exclusion as a bucket – my-bucket, a scope – my-bucket.my-scope, or a collection – my-bucket.my-scope.my-collection. Buckets may contain periods, and therefore must be escaped – my\.bucket.my-scope, as period is the separator used to delimit scopes and collections. Excluded data cannot overlap e.g. specifying my-bucket and my-bucket.my-scope is illegal. This field cannot be used at the same time as included items.

include: Option<Vec<String>>

Include defines the buckets, scopes or collections that are included in the backup. When this field is set, it implies that by default nothing will be backed up, and data items must be explicitly included. You may define an inclusion as a bucket – my-bucket, a scope – my-bucket.my-scope, or a collection – my-bucket.my-scope.my-collection. Buckets may contain periods, and therefore must be escaped – my\.bucket.my-scope, as period is the separator used to delimit scopes and collections. Included data cannot overlap e.g. specifying my-bucket and my-bucket.my-scope is illegal. This field cannot be used at the same time as excluded items.