pub struct CouchbaseBackupObjectStore {
pub endpoint: Option<CouchbaseBackupObjectStoreEndpoint>,
pub secret: Option<String>,
pub uri: Option<String>,
pub use_iam: Option<bool>,
}Expand description
ObjectStore allows for backing up to a remote cloud storage.
Fields
endpoint: Option<CouchbaseBackupObjectStoreEndpoint>Endpoint contains the configuration for connecting to a custom Azure/S3/GCP compliant object store.
If set will override CouchbaseCluster.spec.backup.objectEndpoint
See https://docs.couchbase.com/server/current/backup-restore/cbbackupmgr-cloud.html#compatible-object-stores
secret: Option<String>ObjStoreSecret must contain two fields, access-key-id, secret-access-key and optionally either region or refresh-token. These correspond to the fields used by cbbackupmgr https://docs.couchbase.com/server/current/backup-restore/cbbackupmgr-backup.html#optional-2
uri: Option<String>URI is a reference to a remote object store. This is the prefix of the object store and the bucket name. i.e s3://bucket, az://bucket or gs://bucket.
use_iam: Option<bool>Whether to allow the backup SDK to attempt to authenticate
using the instance metadata api.
If set, will override CouchbaseCluster.spec.backup.useIAM.