pub struct CouchbaseClusterLoggingAuditGarbageCollectionSidecar {
pub age: Option<String>,
pub enabled: Option<bool>,
pub image: Option<String>,
pub interval: Option<String>,
pub resources: Option<CouchbaseClusterLoggingAuditGarbageCollectionSidecarResources>,
}Expand description
DEPRECATED - by spec.logging.audit.rotation for Couchbase Server 7.2.4+ Provide the sidecar configuration required (if so desired) to automatically clean up audit logs.
Fields
age: Option<String>The minimum age of rotated log files to remove, defaults to one hour.
enabled: Option<bool>Enable this sidecar by setting to true, defaults to being disabled.
image: Option<String>Image is the image to be used to run the audit sidecar helper. No validation is carried out as this can be any arbitrary repo and tag.
interval: Option<String>The interval at which to check for rotated log files to remove, defaults to 20 minutes.
resources: Option<CouchbaseClusterLoggingAuditGarbageCollectionSidecarResources>Resources is the resource requirements for the cleanup container. Will be populated by Kubernetes defaults if not specified.