pub struct CouchbaseClusterAutoResourceAllocation {
pub cpu_limits: Option<String>,
pub cpu_requests: Option<String>,
pub enabled: Option<bool>,
pub overhead_percent: Option<i64>,
}Expand description
AutoResourceAllocation populates pod resource requests based on the services running
on that pod. When enabled, this feature will calculate the memory request as the
total of service allocations defined in spec.cluster, plus an overhead defined
by spec.autoResourceAllocation.overheadPercent.Changing individual allocations for
a service will cause a cluster upgrade as allocations are modified in the underlying
pods. This field also allows default pod CPU requests and limits to be applied.
All resource allocations can be overridden by explicitly configuring them in the
spec.servers.resources field.
Fields
cpu_limits: Option<String>CPULimits automatically populates the CPU limits across all Couchbase server pods. This field defaults to “4” CPUs. Explicitly specifying the CPU limit for a particular server class will override this value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#resource-units-in-kubernetes
cpu_requests: Option<String>CPURequests automatically populates the CPU requests across all Couchbase server pods. The default value of “2”, is the minimum recommended number of CPUs required to run Couchbase Server. Explicitly specifying the CPU request for a particular server class will override this value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#resource-units-in-kubernetes
enabled: Option<bool>Enabled defines whether auto-resource allocation is enabled.
overhead_percent: Option<i64>OverheadPercent defines the amount of memory above that required for individual services on a pod. For Couchbase Server this should be approximately 25%.